@@ -522,291 +522,3 @@ impl<'a> Formatter<'a> {
         });
     }
 }
-
-#[cfg(test)]
-mod tests {
-    use std::{
-        collections::{BTreeMap, BTreeSet},
-        ops,
-    };
-
-    use super::*;
-
-    #[derive(DebugPls, Copy, Clone, Hash, PartialEq, Eq, PartialOrd, Ord)]
-    #[dbg_pls(crate = "crate")]
-    pub struct Demo {
-        foo: i32,
-        bar: &'static str,
-    }
-
-    #[test]
-    fn debug_struct() {
-        let val = Demo {
-            foo: 5,
-            bar: "hello",
-        };
-        assert_eq!(pretty(&val).to_string(), r#"Demo { foo: 5, bar: "hello" }"#);
-    }
-
-    #[test]
-    fn debug_struct_big() {
-        let val = Demo {
-            foo: 5,
-            bar: "Hello, world! I am a very long string",
-        };
-        assert_eq!(
-            pretty(&val).to_string(),
-            r#"Demo {
-    foo: 5,
-    bar: "Hello, world! I am a very long string",
-}"#
-        );
-    }
-
-    #[test]
-    fn debug_nested_struct() {
-        let mut val = [Demo {
-            foo: 5,
-            bar: "hello",
-        }; 10];
-        val[6].bar = "Hello, world! I am a very long string";
-
-        assert_eq!(
-            pretty(&val).to_string(),
-            r#"[
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo {
-        foo: 5,
-        bar: "Hello, world! I am a very long string",
-    },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-    Demo { foo: 5, bar: "hello" },
-]"#
-        );
-    }
-
-    #[test]
-    fn debug_small_set() {
-        let set = BTreeSet::from([420, 69]);
-
-        assert_eq!(
-            pretty(&set).to_string(),
-            r#"{
-    69;
-    420
-}"#
-        );
-    }
-
-    #[test]
-    fn debug_nested_set() {
-        let set = BTreeSet::from([
-            Demo {
-                foo: 5,
-                bar: "hello",
-            },
-            Demo {
-                foo: 5,
-                bar: "Hello, world! I am a very long string",
-            },
-        ]);
-
-        assert_eq!(
-            pretty(&set).to_string(),
-            r#"{
-    Demo {
-        foo: 5,
-        bar: "Hello, world! I am a very long string",
-    };
-    Demo { foo: 5, bar: "hello" }
-}"#
-        );
-    }
-
-    #[test]
-    fn debug_map() {
-        let map = BTreeMap::from([("hello", 60), ("Hello, world! I am a very long string", 12)]);
-
-        assert_eq!(
-            pretty(&map).to_string(),
-            r#"{
-    ["Hello, world! I am a very long string"] = 12;
-    ["hello"] = 60;
-}"#
-        );
-    }
-
-    #[test]
-    fn debug_nested_map() {
-        let map = BTreeMap::from([
-            (
-                Demo {
-                    foo: 5,
-                    bar: "hello",
-                },
-                60,
-            ),
-            (
-                Demo {
-                    foo: 5,
-                    bar: "Hello, world! I am a very long string",
-                },
-                12,
-            ),
-        ]);
-
-        assert_eq!(
-            pretty(&map).to_string(),
-            r#"{
-    [
-        Demo {
-            foo: 5,
-            bar: "Hello, world! I am a very long string",
-        },
-    ] = 12;
-    [Demo { foo: 5, bar: "hello" }] = 60;
-}"#
-        );
-    }
-
-    #[derive(DebugPls)]
-    #[dbg_pls(crate = "crate")]
-    pub struct Generic<T> {
-        arg: T,
-    }
-
-    #[test]
-    fn debug_generic() {
-        let generic = Generic { arg: "string" };
-        assert_eq!(pretty(&generic).to_string(), r#"Generic { arg: "string" }"#);
-    }
-
-    #[derive(DebugPls)]
-    #[dbg_pls(crate = "crate")]
-    pub enum Option2<T> {
-        Some(T),
-        None,
-        Wtf { foo: i32 },
-    }
-
-    #[test]
-    fn debug_enum_generic() {
-        let some = Option2::Some(42);
-        assert_eq!(pretty(&some).to_string(), r#"Some(42)"#);
-
-        let none = Option2::<i32>::None;
-        assert_eq!(pretty(&none).to_string(), r#"None"#);
-
-        let wtf = Option2::<i32>::Wtf { foo: 42 };
-        assert_eq!(pretty(&wtf).to_string(), r#"Wtf { foo: 42 }"#);
-    }
-
-    #[derive(DebugPls)]
-    #[dbg_pls(crate = "crate")]
-    pub struct LinkedList {
-        value: i32,
-        next: Option<Box<LinkedList>>,
-    }
-
-    #[test]
-    fn debug_recursive() {
-        let y = LinkedList {
-            value: 1_i32,
-            next: None,
-        };
-        assert_eq!(
-            pretty(&y).to_string(),
-            r#"LinkedList { value: 1, next: None }"#
-        );
-
-        let x = LinkedList {
-            value: 0_i32,
-            next: Some(Box::new(y)),
-        };
-        assert_eq!(
-            pretty(&x).to_string(),
-            r#"LinkedList {
-    value: 0,
-    next: Some(LinkedList { value: 1, next: None }),
-}"#
-        );
-    }
-
-    #[derive(DebugPls)]
-    #[dbg_pls(crate = "crate")]
-    pub struct LinkedList2<T> {
-        value: T,
-        next: Option<Box<LinkedList2<T>>>,
-    }
-
-    #[test]
-    fn debug_recursive2() {
-        let y = LinkedList2 {
-            value: 1_i32,
-            next: None,
-        };
-        assert_eq!(
-            pretty(&y).to_string(),
-            r#"LinkedList2 {
-    value: 1,
-    next: None,
-}"#
-        );
-
-        let x = LinkedList2 {
-            value: 0_i32,
-            next: Some(Box::new(y)),
-        };
-        assert_eq!(
-            pretty(&x).to_string(),
-            r#"LinkedList2 {
-    value: 0,
-    next: Some(LinkedList2 {
-        value: 1,
-        next: None,
-    }),
-}"#
-        );
-    }
-
-    #[derive(DebugPls)]
-    #[dbg_pls(crate = "crate")]
-    pub struct Rangeful<T> {
-        range: ops::Range<T>,
-        range_from: ops::RangeFrom<T>,
-        range_to: ops::RangeTo<T>,
-        range_full: ops::RangeFull,
-        range_inclusive: ops::RangeInclusive<T>,
-        range_inclusive_to: ops::RangeToInclusive<T>,
-    }
-
-    #[test]
-    fn ranges() {
-        let x = Rangeful {
-            range: 1..4,
-            range_from: 1..,
-            range_to: ..7,
-            range_full: ..,
-            range_inclusive: 1234..=1236,
-            range_inclusive_to: ..=70,
-        };
-
-        assert_eq!(
-            pretty(&x).to_string(),
-            r#"Rangeful {
-    range: 1..4,
-    range_from: 1..,
-    range_to: ..7,
-    range_full: ..,
-    range_inclusive: 1234..=1236,
-    range_inclusive_to: ..=70,
-}"#
-        );
-    }
-}
